OiRA

Help

1. Suunnittelu
2. Osallistuminen ja yhteistyö
3. Tunnistaminen + Arviointi
4. Toimintasuunnitelma
5. Raportti
6. Riskinarvioinnin tila 0%

# Lataa ja tulosta raporttisi

Suosittelemme pitämään yrityksessäsi jatkuvasti esillä päivitettyä versiota riskinarviointiraportistasi !

Raportti

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Toimintasuunnitelma

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Yhteenveto riskeistä

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Yhteenveto toteutettavista toimenpiteistä

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More